@@ -3,6 +3,7 @@
  * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
  * SPDX-License-Identifier: Apache-2.0.
  */
+#include <aws/crt/Utility.h>
 #include <utility>
 
 namespace Aws
@@ -77,6 +78,12 @@ namespace Aws
                 }
             }
 
+            template <typename... Args> explicit Optional(Aws::Crt::InPlaceT, Args &&...args)
+            {
+                new (m_storage) T(std::forward<Args>(args)...);
+                m_value = reinterpret_cast<T *>(m_storage);
+            }
+
             Optional &operator=(const Optional &other)
             {
                 if (this == &other)
@@ -170,6 +177,16 @@ namespace Aws
                 return *this;
             }
 
+            template <typename... Args> T &emplace(Args &&...args)
+            {
+                reset();
+
+                new (m_storage) T(std::forward<Args>(args)...);
+                m_value = reinterpret_cast<T *>(m_storage);
+
+                return *m_value;
+            }
+
             const T *operator->() const { return m_value; }
             T *operator->() { return m_value; }
             const T &operator*() const & { return *m_value; }
